get_conversation_info

Function get_conversation_info 

pub async fn get_conversation_info(
    tx: &mut PgConnection,
    user_id: Option<Uuid>,
    anonymous_token: Option<String>,
    chatbot_configuration_id: Uuid,
    conversation_id: Option<Uuid>,
) -> ModelResult<ChatbotConversationInfo>
Gets specific conversation or latest conversation for the user, if any. If conversation_id is not provided then latest conversation is given. Also inlcudes information about the chatbot so that the chatbot ui can be rendered using the information.