pub async fn get_current_conversation_info(
tx: &mut PgConnection,
user_id: Option<Uuid>,
anonymous_token: Option<String>,
chatbot_configuration_id: Uuid,
) -> ModelResult<ChatbotConversationInfo>Expand description
Gets the current conversation for the user, if any. Also inlcudes information about the chatbot so that the chatbot ui can be rendered using the information.